@@ -4,7 +4,7 @@ import snow_pyrepl as pyrepl
 from typing import Optional
 from replit.database import Database
 
-__version__ = "1.1.0"
+__version__ = "1.1.1"
 homedir = Path.home()
 homedir = str(homedir).replace("\\", "/")
 try:
@@ -425,7 +425,7 @@ def user(usr:str):
 	bio = r['bio']
 	icon = r['icon']['url']
 	topLangs = " | ".join(r['topLanguages'])
-	if r['hacker']:
+	if 'hacker' in r:
 		hacker = "{Hacker}"
 	else:
 		hacker = ""
